@@ -1,9 +1,9 @@
 package App::lcpan::Cmd::deps_unindexed;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-26'; # DATE
+our $DATE = '2021-06-01'; # DATE
 our $DIST = 'App-lcpan-CmdBundle-deps'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,8 +66,8 @@ including ones to 'perl'.
 _
             schema => 'bool*',
             cmdline_aliases => {
-                exclude_perl => {is_flag=>1, summary=>"Equivalent to --perl", code=>sub {$_[0]{perl}=1}},
-                include_perl => {is_flag=>1, summary=>"Equivalent to --no-perl", code=>sub {$_[0]{perl}=0}},
+                exclude_perl => {is_flag=>1, summary=>"Equivalent to --perl", code=>sub {$_[0]{perl}=0}},
+                include_perl => {is_flag=>1, summary=>"Equivalent to --no-perl", code=>sub {$_[0]{perl}=1}},
             },
         },
     },
@@ -161,7 +161,7 @@ App::lcpan::Cmd::deps_unindexed - List all unindexed dependencies
 
 =head1 VERSION
 
-This document describes version 0.009 of App::lcpan::Cmd::deps_unindexed (from Perl distribution App-lcpan-CmdBundle-deps), released on 2021-05-26.
+This document describes version 0.010 of App::lcpan::Cmd::deps_unindexed (from Perl distribution App-lcpan-CmdBundle-deps), released on 2021-06-01.
 
 =head1 DESCRIPTION
 
@@ -225,12 +225,12 @@ Relationship (can contain % for SQL LIKE query).
 
 Returns an enveloped result (an array).
 
-First element ($status_code) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-($reason) is a string containing error message, or "OK" if status is
-200. Third element ($payload) is optional, the actual result. Fourth
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
 element (%result_meta) is called result metadata and is optional, a hash
-that contains extra information.
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
